@@ -170,6 +170,7 @@ class CAE_B3U4I:
         self.current = [0] * 4
         self.voltage = [0] * 3
         self.energy = [0] * 3
+        self.maxsize = sys.maxsize
         self.run = False
 
     def start(self):
@@ -350,13 +351,13 @@ class CAE_B3U4I:
             if self.result_cnt != self.old_result_cnt:
                 self.old_result_cnt = self.result_cnt
                 self.energy[0] += energy_val * self.power[0]
-                if self.energy[0] > sys.maxsize:
+                if self.energy[0] > self.maxsize:
                     self.energy[0] = 0
                 self.energy[1] += energy_val * self.power[1]
-                if self.energy[1] > sys.maxsize:
+                if self.energy[1] > self.maxsize:
                     self.energy[1] = 0
                 self.energy[2] += energy_val * self.power[2]
-                if self.energy[2] > sys.maxsize:
+                if self.energy[2] > self.maxsize:
                     self.energy[2] = 0
         return self.energy
 
@@ -488,6 +489,7 @@ class CAE_G2Mi2Ao:
         self.oldPulse2 = 0
         self.pulse_sum1 = 0
         self.pulse_sum2 = 0
+        self.maxsize = sys.maxsize
         self.run = False
 
     def start(self):
@@ -667,7 +669,7 @@ class CAE_G2Mi2Ao:
                 self.pulse_sum1 += 1 if impuls_freq == 0 else impuls_freq
                 self.oldPulse1 = pulse
             lock.release()
-        if self.pulse_sum1 >= sys.maxsize:
+        if self.pulse_sum1 >= self.maxsize:
             self.pulse_sum1 = 0
         return self.pulse_sum1
 
@@ -705,7 +707,7 @@ class CAE_G2Mi2Ao:
                 self.pulse_sum2 += 1 if impuls_freq == 0 else impuls_freq
                 self.oldPulse2 = pulse
             lock.release()
-        if self.pulse_sum2 >= sys.maxsize:
+        if self.pulse_sum2 >= self.maxsize:
             self.pulse_sum2 = 0
         return self.pulse_sum2
 
